@@ -5,7 +5,7 @@ use Moo::_Utils;
 use B 'perlstring';
 use Sub::Defer ();
 
-our $VERSION = '0.091014'; # 0.91.14
+our $VERSION = '1.000000'; # 1.0.0
 $VERSION = eval $VERSION;
 
 require Moo::sification;
@@ -226,19 +226,30 @@ and else where
 
 =head1 DESCRIPTION
 
-This module is an extremely light-weight, high-performance L<Moose> replacement.
+This module is an extremely light-weight subset of L<Moose> optimised for
+rapid startup and pay for what you use.
+
 It also avoids depending on any XS modules to allow simple deployments.  The
 name C<Moo> is based on the idea that it provides almost -but not quite- two
 thirds of L<Moose>.
 
-Unlike C<Mouse> this module does not aim at full L<Moose> compatibility.  See
-L</INCOMPATIBILITIES> for more details.
+Unlike C<Mouse> this module does not aim at full compatibility with
+L<Moose>'s surface syntax, preferring instead of provide full interoperability
+via the metaclass inflation capabilites described in L</MOO AND MOOSE>.
+
+For a full list of the minor differences between L<Moose> and L<Moo>'s surface
+syntax, see L</INCOMPATIBILITIES>.
 
 =head1 WHY MOO EXISTS
 
 If you want a full object system with a rich Metaprotocol, L<Moose> is
 already wonderful.
 
+However, sometimes you're writing a command line script or a CGI script
+where fast startup is essential, or code designed to be deployed as a single
+file via L<App::FatPacker>, or you're writing a CPAN module and you want it
+to be usable by people with those constraints.
+
 I've tried several times to use L<Mouse> but it's 3x the size of Moo and
 takes longer to load than most of my Moo based CGI scripts take to run.
 
@@ -246,42 +257,47 @@ If you don't want L<Moose>, you don't want "less metaprotocol" like L<Mouse>,
 you want "as little as possible" - which means "no metaprotocol", which is
 what Moo provides.
 
-By Moo 1.0 I intend to have Moo's equivalent of L<Any::Moose> built in -
-if Moose gets loaded, any Moo class or role will act as a Moose equivalent
-if treated as such.
+Better still, if you install and load L<Moose>, we set up metaclasses for your
+L<Moo> classes and L<Moo::Role> roles, so you can use them in L<Moose> code
+without ever noticing that some of your codebase is using L<Moo>.
 
 Hence - Moo exists as its name - Minimal Object Orientation - with a pledge
 to make it smooth to upgrade to L<Moose> when you need more than minimal
 features.
 
-=head1 Moo and Moose - NEW, EXPERIMENTAL
+=head1 MOO AND MOOSE
 
 If L<Moo> detects L<Moose> being loaded, it will automatically register
 metaclasses for your L<Moo> and L<Moo::Role> packages, so you should be able
-to use them in L<Moose> code without it ever realising you aren't using
+to use them in L<Moose> code without anybody ever noticing you aren't using
 L<Moose> everywhere.
 
-Extending a L<Moose> class or consuming a L<Moose::Role> should also work.
+Extending a L<Moose> class or consuming a L<Moose::Role> will also work.
 
-So should extending a L<Mouse> class or consuming a L<Mouse::Role>.
+So will extending a L<Mouse> class or consuming a L<Mouse::Role> - but note
+that we don't provide L<Mouse> metaclasses or metaroles so the other way
+around doesn't work. This feature exists for L<Any::Moose> users porting to
+L<Moo>, enabling L<Mouse> users to use L<Moo> classes is not a priority for us.
 
 This means that there is no need for anything like L<Any::Moose> for Moo
 code - Moo and Moose code should simply interoperate without problem. To
 handle L<Mouse> code, you'll likely need an empty Moo role or class consuming
 or extending the L<Mouse> stuff since it doesn't register true L<Moose>
-metaclasses like we do.
+metaclasses like L<Moo> does.
 
-However, these features are new as of 0.91.0 (0.091000) so while serviceable,
-they are absolutely certain to not be 100% yet; please do report bugs.
+If you want types to be upgraded to the L<Moose> types, use
+L<MooX::Types::MooseLike> and install the L<MooseX::Types> library to
+match the L<MooX::Types::MooseLike> library you're using - L<Moo> will
+load the L<MooseX::Types> library and use that type for the newly created
+metaclass.
 
 If you need to disable the metaclass creation, add:
 
   no Moo::sification;
 
 to your code before Moose is loaded, but bear in mind that this switch is
-currently global and turns the mechanism off entirely, so don't put this
-in library code, only in a top level script as a temporary measure while
-you send a bug report.
+currently global and turns the mechanism off entirely so don't put this
+in library code.
 
 =head1 IMPORTED METHODS
 
@@ -720,6 +736,8 @@ perigrin - Chris Prather (cpan:PERIGRIN) <chris@prather.org>
 
 Mithaldu - Christian Walde (cpan:MITHALDU) <walde.christian@googlemail.com>
 
+ilmari - Dagfinn Ilmari Mannsåker (cpan:ILMARI) <ilmari@ilmari.org>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2010-2011 the Moo L</AUTHOR> and L</CONTRIBUTORS>
